Monty Python's Flying Circus: Just the Words - Episode 40

# Episode Forty: The golden age of ballooning

Montgolfier Brothers
Louis XIV
George III
Party Political Broadcast on Behalf of the Norwegian Party
Zeppelin

Colour code: Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Animation of balloons ascending.
| CAPTION: 'THE GOLDEN AGE OF BALLOONING'
| CAPTION: 'THE BEGINNINGS'
| Cut to a suburban bathroom. A plumber with a bag of tools open beside him is doing an elaborate repair on the toilet. He is in rather an awkward position.
Plumber | (working away) The Golden Age of Ballooning can be said to begin in 1783 ... when the Montgolfier brothers made their first ascent in a fire balloon. On the eve of that ... (struggling with the work) come on... come on... momentous ascent, the brothers took one last look at their craft, as it stood on the field of Annencay.
| Pleasant elegant eighteenth-century music. Mix to a French small country-house interior. At the window Joseph and Jacques Montgolfier are looking out at their balloon. In the background a plumber is working away at a bit of eighteenth-century French piping.
Jacques | This is a great moment for us, Joseph.
Joseph | It is a great moment for France.
Jacques | Ah, oui!
Joseph | First ascent in a hot-air balloon, by the Montgolfier brothers - 1783 ... I can see us now... just after Montesquieu and just before Mozart.
Jacques | I think I'll go and wash ...
Joseph | Good luck.
Jacques | Oh ... it's quite easy, really ... I just slap a little water on my face, then...
Joseph | No... good luck for tomorrow.
Jacques | Oh I see, yes. You too. Yours has been the work.
Joseph | Let us hope for a safe ascent... and don't use my flannel.
Jacques | You know, when you showed me the plans in Paris, I could not believe that we should be the first men who would fly.
Joseph | Yes ... it's wonderful.
Jacques | I am so excited I could hardly wash.
Joseph | Yes ... I too have had some difficulty washing these past few days.
Jacques | Still, what is washing when we are on the verge of a great scientific breakthrough?
Joseph | Jacques...
Jacques | Yes, Joseph...
Joseph | I have not been washing very thoroughly for many years now.
Jacques | What do you mean? You must have been washing your face?
Joseph | Oh yes, my face, I wash my face... but my legs... my stomach ... my chest, they're filthy.
Jacques | Well, I don't wash my stomach every day.
Joseph | (with increasing self-remorse) Ah, but you wash far more than me ... you are the cleaner of the Montgolfier brothers.
Jacques | This is nothing, Joseph...
| A very formal butler enters.
Butler | Monsieur Montgolfier.. A Mr Parfitt to see you, sir.
| A head appears round the door and corrects the butler, in a very stage whisper.
Mr Bartlett | No, no... no... Bartlett! (the head disappears again)
Butler | A Mr Barklit, to see you, sir.
Mr Bartlett | No! Bartlett with a 't'. (the head disappears again)
Butler | (with difficulty) Barr ... at ... elett ... to see you, sir.
Mr Bartlett | Bartlett (he disappears again)
Butler | Barkit...
Mr Bartlett | Bartlett!
Butler | Baffle... Bartlett... A Mr Bartlett to see you, sir.
Joseph | I don't want to see anyone, O'Toole... tell him to go away.
Butler | Thank you, sir. (he exits)
Jacques | Well, it's getting late. I must go and have a wash.
Joseph | What will you be washing?
Jacques | Oh ... just my face and neck ... perhaps my feet... and possibly ... but no ... no ... lock up the plans, Joseph... tomorrow they will make us the toast of France. 'The first ascent by the Montgolfier brothers in a balloon'. Just after Ballcock and just before Bang... what a position!
| Some men have now entered the room, chosen a spot and are briskly but quietly setting up a screen and a projector, The projector is turned on and a film comes up on the screen together with triumphant music, applause and commentary. We zoom in to the screen. It shows an animation of two naked men boxing in a large tub of water.
Voice Over | So, on June 7th, 1783, the Montgolfier brothers had a really good wash ... starting on his face and arms, Joseph Michael Montgolfier went on to scrub his torso, his legs and his naughty bits, before rinsing his whole body. That June night, he and his brother between them washed seventeen square feet of body area. They used a kilo and a half of catholic soap and nearly fourteen gallons of nice hot water. It was indeed an impressive sight.
| Music crescendo.
| CAPTION: 'THE END'
| Picture of a balloon.
| SUPERIMPOSED CAPTION: 'THE GOLDEN AGE OF BALLOONING'.
| This is over the BBC 2 logo.
Voice Over | Next week on 'The Golden Age of Ballooning', we examine the work of Girlsher and Coxwell, the English balloonists who ascended to a height of seven miles in 1862 without washing. There is also a book called 'The Golden Age of Ballooning' published by the BBC to coincide with the series. It's in an attractive hand-tooled binding, is priced £5 and failure to buy it will make you liable to a £50 fine or three months' imprisonment. There's also a record of someone reading the book of 'The Golden Age of Ballooning', a crochet-work bedspread with the words 'The Golden Age of Ballooning' on it, available from the BBC, price £18 or five months' imprisonment and there are matching toilet-seat covers and courtesy mats with illustrations of many of the baboons mentioned. Also available is a life-size model frog which croaks the words 'The Golden Age of Ballooning' and an attractive bakelite case for storing motorway construction plans in, made in the shape of a balloon. And now, another chance to see a repeat of this morning's re-run of last night's second showing of episode two of the award-winning series 'The Golden Age of Ballooning'.
| ANIMATION: balloons ascending as before.
| CAPTION: 'THE GOLDEN AGE OF BALLOONING' CAPTION: 'EPISODE TWO: THE MONTGOLFIER BROTHERS IN LOVE' CAPTION: 'NOT WITH EACH OTHER, OBVIOUSLY'
| Joseph Montgolfier's workshop. We see plans and drawing boards, and at one end of the room, Joseph's fiancee, Antoinette, in a pretty dress. She is hanging suspended in a harness horizontally, attached to a gas bag. In other words she is fioating like the bottom half of an airship. Joseph is making calculations excitedly. Occasionally he goes over to her, takes a measurement and goes back to his desk to write it down.
Antoinette | Oh Joseph, all you think about is balloons... all you talk about is balloons. Your beautiful house is full of bits and pieces of balloons... your books are all about balloons... every time you sing a song, it is in some way obliquely connected with balloons... everything you eat has to have 'balloon' incorporated in the title... your dogs are an called 'balloonno'... you tie balloons to your ankles in the evenings.
Joseph | I don't do that!
Antoinette | Well, no, you don't do that, but you do duck down and shout 'Hey! Balloons!' when there are none about. Your whole life is becoming obsessively balloonic, you know. Why do I have to hang from this bloody gas bag all day? Don't I mean anything to you?
Joseph | (busy measuring) Oh ma cherie, you mean more to me than any heavier than air dirigible could ever...
Antoinette | Oh there you go again!
Joseph | Don't waggle!
| Jacques enters.
Jacques | I've run your bath for you, Joseph. (he sees Antoinette) Oh... I'm so sorry, I didn't realize.
Joseph | It's all right, we've done the difficult bit.
Jacques | Well, don't forget we have our special guest coming this evening.
Joseph | Oh?
Jacques | Don't tell me you have forgotten already. The man who is giving us thousands of francs for our experiments.
Joseph | What man?
Jacques | Louis XIV!
Joseph | Isn't he dead?
Jacques | Evidently not...
Joseph | All right, I'll be round.
Jacques | Oh, and Joseph...
Joseph | Yes, Jacques?
Jacques | You will... wash... won't you?
Joseph | Yes, of course!
| CAPTION: 'LATER THAT EVENING'
| Fade up on the Montgolfiers' sitting room. Jacques sits there rather nervously. The plumber is working away. The door opens and the butler appears.
Butler | His Royal Majesty, Louis XIV of France.
| Mr Bartlett's head pops in and whispers loudly to butler.
Mr Bartlett | And Mr Bartlett.
| The butler pushes him aside. Fanfare. Enter Louis XIV and two tough-looking advisers. He is resplendent in state robes.
Jacques | Your Majesty. It's a great privilege. Welcome to our humble abode.
Louis | (in very broad Glaswegian accent) It's er... very nice to be here.
Jacques | (calling) O'Toole.
Butler | Sir?
Jacques | Claret for His Majesty please.
Butler | There's a Mr Barttett outside again, sir.
Jacques | Not now, I can't see him, we have the King of France here.
Butler | Yes, sir.
| He exits. Jacques and the king stand in rather embarrassed silence. Jacques eventually speaks.
Jacques | Your Majesty. You had a pleasant journey, I trust?
Louis | Yes... yes, oh definitely... yes... yes. Oh aye, aye.
| Silence.
Jacques | You have come from Paris?
Louis | Where?
Jacques | From Paris... you have travelled from Paris?
Louis | Oh yes, we've come from Paris... yes... yes, yes, we've just come from... er... Paris... yes.
| The butler comes back in.
Butler | Sir?
Jacques | Yes, O'Toole?
Butler | Which one is the claret, sir?
Jacques | The claret is in the decanter.
Butler | The wooden thing?
Jacques | No no... the glass thing... the glass decanter with the round glass stopper.
Butler | Oh yes, behind the door.
Jacques | No no... on the sideboard.
Butler | The sideboard?
Jacques | The sideboard... yes. Look... you go into the salle à manger ... the dining room, right? - and the sideboard is on your left, by the wall, beside the master's portrait.
Butler | Ah! Above the mirror, sir?
Jacques | No! No! The mirror is on the other side. It's opposite the mirror.
Butler | But that's the table, sir.
Jacques | No... you don't go as far as the table. You go into the room, right?... on your right is the door to the orangery, straight ahead of you is the door to the library, and to your left is the sideboard.
Butler | Ah, yes, I see, sir...
Jacques | And the claret is on top of the sideboard, to the left.
Butler | On the left.
Jacques | Yes...
Butler | As one looks at it, sir?
Jacques | Yes.
Butler | I see, sir, thank you. (he turns to go)
Jacques | O'Toole.
Butler | Yes, sir.
Jacques | Will you please tell Monsieur Joseph our guest is here.
Butler | Yes, sir.
| He leaves. There is another embarrassed silence.
Jacques | I'm sorry about that, Your Majesty.
Butler | (re-entering) Apparently, sir, there is a plan to build a canal between the two Egyptian towns of..,
Jacques | Not now, O'Toole!
| The butler exits. More silence.
Louis | Well... er... Mr Montgolfier... let's not beat around the bush ... my... dukes and I are very busy men. What we'd like to do is see the plans of your proposed balloon... if that's at all possible.
Jacques | Certainly, Your Majesty... I have them here ready prepared.
Louis | Oh, great .... then... what we would like to do ... is er... to take them back with us for the Royal Archives of er...
First Duke | (also Glaswegian) France.
Louis | France, aye.
Jacques | Well, it is indeed a great honour Your Majesty, that I cannot refuse.
Louis | Right! OK! Let's get 'em.
| He and his two dukes are suddenly galvanized into action. They are about to grab the plans when Joseph enters, clad only in a towel and rather silly bath hat.
Joseph | Just a moment!
Jacques | Joseph!
Joseph | (indicating the king) This man is not Louis XIV!
Jacques | Joseph! Are you out of your mind!
Joseph | I've been looking it up in my bath. Louis XIV died in 1717. It's now 1783! Answer me that!
Louis | Did I say Louis XIV? Oh, sorry, I meant Louis XV... Louis XV.
Joseph | He died in 1774!
| Louis, getting rather hot and angry, comes over to Joseph belligerently.
Louis | All right, Louis XVI!... listen to me, smartarse, when you're King of France,... you've got better things to do than go around all day remembering your bloody number.
| Putting his face very close to Joseph's. He butts him sharply and viciously on the bridge of the nose with his forehead in the time-honoured Glaswegian way.
Joseph | Aaaaaarh!
| He reels away, clutching his nose in agony. Louis approaches Jacques, equally belligerently.
Louis | Right! You want to argue about numbers?
Jacques | Er... no, no.
Louis | Right, well... lets get hold of the plans for the Royal Archives. We've got to get back to... er...
First Duke | Paris.
Louis | Paris by tonight so get a move on..
Joseph | Aaaargh! Ow! Ooooohh!
| The butler reappears.
Butler | I got as far as the sideboard, sir...
| Louis and his dukes grab the plans and push past the butler and across to an open window. There is a bit of a scuffle at the window as they are clambering out at the same time as two men in black with a projector and screen are clambering in.
Joseph | Stop them... oh! Ah... oooooohh!
Butler | (to Jacques) No news on the canal I'm afraid, sir, but apparently in India they're thinking of building a railway between the towns of Lahore...
Joseph | Stop... ow! Stop them, O'Toole for... oh! shit! God's sake... stop them, they've got the plans! (he rushes to the window)
| By now the men in black have set up the screen. On the screen comes film of Louis and his men racing through the gardens away from the Montgolfier' s home.
Voice Over | Will Louis XVI get away with the Montgolfiers' precious plans? Is sixteen years of work to be stolen by this suspect sovereign? Is France really in the grip of a Glaswegian monarch? Watch next week's episode of 'The Golden Age of Ballooning'... Now!
| Cut to animation/titles as before. Music.
| CAPTION: 'THE GOLDEN AGE OF BALLOONING'
| CAPTION: 'EPISODE THREE: THE GREAT DAY FOR FRANCE'
| Cut to a TV discussion in progress. An urgent, impressive current affairs show called 'Derision '. Two opulent-looking men and a presenter.
| SUPERIMPOSED CAPTION: 'SIR CHARLES DIVIDENDS'
Sir Dividends | ... But now that the Government has collapsed ... and shown itself incapable of providing any sort of unifying force, I feel we do need the stability and the breathing space that a military presence would provide.
Presenter | Lord Interest?
| SUPERIMPOSED CAPTION: 'LORD INTEREST'
Lord Interest | Oh yes... I agree that the army should take over, but I think it should not interfere with the programme of street executions, which I feel have been the shot in the arm that the British economy so desperately needed.
| As they drone on, the presenter turns away from them to talk softly into the camera.
Presenter | The Montgolfier brothers' plans did indeed turn up... six months later, and a long way from Paris, at the court of King George III of England.
| Cut to a throne room. George III is being read to by an adviser.
| CAPTION: 'THE COURT OF GEORGE III, 1781'
Reader | ... Titty was very worried. Where could Mary be? He looked everywhere. Under the stones and behind the bushes... and Mr Squirrel helped him by looking up in the trees, and Mr Badger helped him by looking under the ground...
| There is a knock on the door. George III looks up quickly. The reader, with obvoiously well practiced skill, shuts the book, slips it beneath another book which he opens and carries on reading.
Reader | ... and so, Your Majesty, we the Commons do herein crave and beseech that...
George III | Enter!
| Lord North enters and bows briefly.
Lord North | Your Majesty... Louis XVIII is here!
George III | Who is Louis XVIII?
Lord North | The King of France, Your Majesty! This is a great moment to have, sir.
George III | There is no Louis XVIII.
| We hear a Scottish voice outside the door. Lord North ducks his head out for a moment, then reappears.
Lord North | He craves Your Majesty's pardon. He has had a long journey here and miscounted... He is Louis XVII.
George III | Louis XVI is dead already?
| A trace of worry crosses North's face. He goes outside the door again for a moment. Sounds of a slight argument between himself and the Glaswegians. Suddenly there is a yell of pain and Lord North reels in holding the bridge of his nose.
Lord North | Aaaaaaaaaaaaghh! Oh my God! Oh... ah... oh Christ!
| Louis strides in with the two dukes. They all wear tam o'shanters.
Louis | (to the reader) Your Majesty, I am Louis XVI... Oh Christ... (to George III) Your Majesty... I am Louis XVI as you so rightly say, and I don't want to muck about. I have a wee proposition which could make the name of George IV the most respected in Europe...
George III | George III
Louis | George III! Sorry. Where can we talk?
Lord North | Oh! God! ... did you see that?... Oh!... aaaargh! Oh dear! (he is in great pain still and clutching his nose)
George III | We shall have a state banquet at St James' Palace!
Louis | No no, look, I can't hang about. It's take it or leave... we got to get back to... er...
First Duke | Paris.
Louis | Paris, by tonight...
George III | Must you leave us, Louis?
Louis | I'd rather just sell the plans and nip off, Georgie boy.
George III | All right... we will buy the plans... if you will undertake to disengage your troops in America.
Louis | Do what?
George III | And, I shall give you £10,000 for the plans...
Louis | Ten thousand pounds! Right, well, we'll disengage the, urn, you know... like you said - we'll disengage 'em... tell you what, then, I'll put a duke on to it... OK? Right!
Lord North | (still clutching his nose) That's the worst thing you can do to anybody.
Louis | You asked for it, sonny.
Lord North | You could have broken my bloody nose!
George III | North! Please!
Lord North | You saw it! It was right on the bone.
George III | North! Will you send for the Duke of Portland ... we have a financial matter to discuss.
Lord North | Well, it really hurt.
Louis | No, look, I think it's better if you give the money to us. We're going back. We've got a bag.
George III | No, no... don't worry, Louis. We shall talk to your Monsieur Necker.
Louis | Ah! Well, actually, we'd rather you didn't... we've been having a wee bit of trouble with him... you know what I mean?
George III | Monsieur Necker? The man who introduced so many valuable reforms and who proved so popular despite his opposition to Mirabeau's policy of issuing 'assignats'?
| SUPERIMPOSED CAPTION: 'THIS SPEECH HAS BEEN VERIFIED BY ENCYCLOPAEDIA BRITANNICA'
Louis | Er... aye, yeah... the trouble is he's been drinking a bit recently ... you' know, fourteen lagers with his breakfast... that sort of thing.
George III | Well... very well, Louis...
| The door flies open and there is Joseph Montgolfier, still clad only in towel and silly bath hat.
Joseph | Just a moment!
Louis | Oh, Christ!
George III | What are you doing?
Joseph | I am Joseph Montgolfier, the inventor of the fire balloon. The man before you is an impostor!
George III | Ooh! I am not ... honestly!
Joseph | No, not you, Your Majesty (he points at Louis) This man - this Louis, the so-called King of France man. Which number did you give this time - Louis the 23rd?
Louis | I got it right!
Joseph | I bet you took a few guesses.
Louis | Listen, you spotty sassenach pillock..
Dr Hamer | (not a doctor but a period butler) Your Majesty! The Ronettes are here.
Bartlett | And Mr Bartlett.
| Three black ladies wearing modern showbiz costumes come in and sing 'George III' song. Two men come in and set up a screen as before.
The Ronettes | (singing) George III ... etc .... etc ....
George III | Oh dear, I'm not supposed to go mad till 1800!
| Louis, arguing violently with the butler, butts him. Music comes up and the sound fades on this strange scene. George III falls to the floor and waggles his legs around in the air. Zoom in as the men in black take cover off the caption.
| CAPTION: 'MEANWHILE, IN FRANCE...'
| Cut to drawing more in the Montgolfiers' house. Jacques is at a table working on some drawings. Behind him Antoinette paces the room nervously. She is still wearing her harness, but it is no longer attached to the gas balloon. In a corner of the room a plumber is still mending the elaborate plumbing.
Antoinette | Joseph has been gone for six months now ... we have heard nothing!
Jacques | He can look after himself.
Antoinette | But he had only on a towel, you know.
| Jacques takes off his false ears and walks over to Antoinette.
Jacques | Antoinette... from now on there is only one Montgolfier brother.
Antoinette | But Louis XIV has the plans... you must wait until Joseph returns.
Jacques | (casually loosening her harness) The plans are here, cherie. (he indicates the desk where he has been working) Let me put my tongue in your mouth.
Antoinette | What do you mean?
Jacques | We're supposed to be French, aren't we?
Antoinette | No, I mean what are the plans which Joseph after is chasing?
Jacques | Please, let me put it in a little way.
Antoinette | Oh, Jacques, ze plans!
Jacques | I take it out if you don't like it.
| He chases her a bit with his tongue out. Antoinette is about to react rather violently one way or the other, when her dramatic moment is cut short by the entrance of O'Toole the butler.
Butler | Are you sure the claret was on the left of the sideboard, sir?
Jacques | Yes, O'Toole, it's always been there.
Butler | Well I'll look for one more month, sir. (he turns and goes out; Jacques eyes Antoinette lasciviously and is about to try and make contact in the French way when the butler returns) By the way sir, Mr Bartlett has gone, sir. He said he couldn't wait any longer.
Jacques | Thank you, O'Toole...
Butler | Not at all, sir... I've enjoyed being in it...
Jacques | (impatiently) Right!
Butler | Thank you, sir... mam'selle.
| He exits. Tremendous applause. He reappears, takes a bow and leaves again. Jacques and Antoinette look nonplussed. He reappears. Terrific applause. He gestures for them to quiet down. Eventually them is silence.
Butler | By the way, sir, Mr Bartlett has gone, sir. (tremendous applause) He said he couldn't wait any longer, sir.
| Incredible volume of laughter here brings the house down. The rest of the scene is pandemonium with laughter developing into prolonged applause.
Jacques | Thank you, O'Toole.
Butler | Not at all, sir ... I've enjoyed being in it.
Jacques | Right!
Butler | Thank you, sir ... mam'selle.
Audience | More! More! More! etc .... etc .... etc ....
| Crescendo of applause. Over shouts of more! More! Superimposed Python credits. The butler is showered with flowers. Fans come on and congratulate him. A BBC security man restrains them. Other members of the cast appear and shake hands, and stand in a row behind, applauding. A dear old middle-aged lady comes in and stands beside him, weeping proudly.
Voice Over | George III was arranged and composed by Neil Innes. He is available from the BBC price £4 or eight months' imprisonment.
| The credits end. Cut to BBC world symbol.
Voice Over | That was episode three of 'The Golden Age of Ballooning'. May I remind you that there's still time to get your 'Golden Age of Ballooning' suppositories direct from the BBC, price £4.50, or £19 for a set of six. Well, in a moment the BBC will be closing down for the night, but first, here is a Party Political Broadcast on behalf of the Norwegian Party.
Norwegian | Ik tvika nasai...
| SUBTITLE: 'GOOD EVENING'
Norwegian | ...Stivianka sobjiord ki niyanska ik takka Norge weginda zokiy yniet...
| SUBTITLE: 'YOU MAY THINK IT STRANGE THAT WE SHOULD BE ASKING YOU TO VOTE NORWEGIAN AT THE NEXT ELECTION'
Norwegian | ...Ik vietta nogiunda sti jibiora...
| SUBTITLE: 'BUT CONSIDER THE ADVANTAGES'
Norwegian | In Norge we hatta svinska offikiose buinni a gogik in Europa.
| SUBTITLE: 'IN NORWAY, WE HAVE ONE OF THE HIGHEST PER CAPPA INCOME RATES IN EUROPE'
Norwegian | Sti glikka in Norge tijik dinstianna gikloosi stijioska kary.
| SUBTITLE: 'WE HAVE AN INDUSTRIAL RE-INVESTMENT RATE OF 14%'
Norwegian | E in Norge we hatta siddinkarvo dikinik chaila osto tykka hennakska.
| SUBTITLE: 'AND GIRLS WITH MASSIVE KNOCKERS!'
Norwegian | Gikkiaski ungurden kola bijiusti stonosse.
| SUBTITLE: 'HONESTLY, THEY'LL DO ANYTHING FOR YOU'
Norwegian | Hijiasgo biunderten ki yikilpa stivvora niski ofidae.
| SUBTITLE: 'THEY'LL GO THROUGH THE CARD'
Norwegian | E stavaskija, E stonioska.
| SUBTITLE: 'YOU NAME IT, THEY KNOW IT'
Norwegian | Stingik oloshoyert okka in Trondheim khi oyplitz...
| SUBTITLE: 'BUT THERE'S ONE IN TRONDHEIM WHO CAN PUT HER...'
| Blackout.
| CAPTION: 'PARTY POLITICAL BROADCAST ON BEHALF OF THE NORWEGIAN PARTY'
Voice Over | Highlights of that broadcast will be discussed later by Lord George-Brown, ex-Foreign Secretary, Mr Sven Olafson, the ex-Norwegian Minister of Finance, Sir Charles Ollendorff, ex-Chairman of the Norwegian Trades Council, Mr Hamish McLavell, the Mayor of Wick, the nearest large town to Norway, Mrs Betty Norday, whose name sounds remarkably like Norway, Mr Brian Waynor, whose name is an anagram of Norway, Mr and Mrs Ford, whose name sounds like Fiord, of which there are a lot in Norway, Ron and Christine Boslo...
| Baloons ascending. The montage as before with music.
| CAPTION: 'THE GOLDEN AGE OF BALLOONING' CAPTION: 'EPISODE SIX: FERDINAND VON ZEPPELIN - PIONEER OF THE AIRSHIP'
| Cut to photo of family, group.
Voice Over | Ferdinand von Zeppelin was born in Constance in 1838, the brother of Barry Zeppelin, the least talented of the fourteen Zeppelin brothers.
| Black and white film of Barry (Terry J) blowing up balloons of increasing size. They all sink to the ground. The last one blows back and inflates him; he rises into the air. Cut to stock film of a zeppelin.
Voice Over | Meanwhile for Ferdinand von Zeppelin, the year 1908 was a year of triumph.
| Cut to interior of a zeppelin. A party. Expensively dressed guests. Champagne. A palm court orchestra playing. Some guests looking out of the windows in wonderment.
Von Bülow | (approaching Zeppelin) Herr Zeppelin - it's wonderful! It's put ballooning right back on the map.
| Zeppelin goes instantly berserk with anger.
Zeppelin | It's not a balloon! D'you hear?... It's not a balloon ... It's an airship ... an airship ... d'you hear?
| He hits him very hard on the top of the head with the underside of his fist.
Von Bülow | Well, it's very nice anyway.
Tirpitz | (to Zeppelin) Tell me, what is the principle of these balloons?
Zeppelin | It's not a balloon! You stupid little thick-headed Saxon git! It's not a balloon! Balloons is for kiddy-winkies. If you want to play with balloons, get outside.
| Drags Tirpitz over to the door, opens it and flings him out into the clouds.
Tirpitz | Aaaaaaaaaghhh!
| Cut to an old German couple in a cottage. The man is reading from a big book, the lady is knitting. The man is in underpants. There are a pair of lederhosen drying in front of the fire.
Helmut | (reading) Yorkshire ... pudding. A type of thick pancake, eaten with large ...
| Roof splitting noise. A thump and the house shakes. They both look up. Cut back to the airship. The party is still going on.
Hollweg | I hear you are to name the balloon after Bismarck?
Zeppelin | (flying into hysterical rage) Bismarck? Of course I'm not calling it after Bismarck. It's a zeppelin. It's nothing to do with bloody Bismarck!
Hollweg | Surely he gave you some money for it?
Zeppelin | Get outside!
| He opens the door and flings Hollweg out. Cut back to the old couple in the cottage.
Helmut | Za... bag... lione... a sort of cream mouse... mousse of Italian origin...
| Roof splintering noise. A thump and the house shakes. Cut back to the airship. A little cluster of people round the door. The party is still going on but there is a little tension in the atmosphere.
Von Bülow | Ferdinand... that was a Minister of State you just threw out of the balloon.
Zeppelin | It's not a balloon! It's an airship!
Von Bülow | All right, I'm sorry.
Zeppelin | All right - go and have a look! (he throws the protesting Von Bülow out) And you!
| Animation of several men being thrown from airship.
Helmut | Zu... cchin... ni ... Italian... ma... flows... (splintering crash, thump, the home shakes) Zingara... A garnish of finely chopped ... or shredded lean ham ... (splintering crash, thump, the house shakes) ... tongue ... (another splintering crash, thump, the house shakes) ... mushrooms and truffles. (same again) ... Zakuski. A Russian ... hors d'oeuvre ... (a very load splintering crash, thump and the house shudders; Mrs Helmut stops knitting and crosses the room to the door and into the next room, where the sounds are coming flora) With tiny pieces of sliced...
Mrs Helmut | (looking in the other room) Oh, look! It's the Chancellor!
| Helmut's hand immediately goes to his tie. He half makes to rise.
Helmut | What? Prince Von Bülow? Here?
Mrs Helmut | Ja!
Helmut | Coming here?
Mrs Helmut | No - he is here.
Helmut | (jumping to his feet) Oh, I must go and put my old uniform on.
Mrs Helmut | He won't notice, Helmut. He's dead.
Helmut | Dead? Here?
Mrs Helmut | Ja. In our sitting room.
Helmut | This is our sitting room, dear.
Mrs Helmut | Well, you know what I mean.
Helmut | (waving his finger at her) The drawing room!
Mrs Helmut | Yes ... but it's a kind of sitting room.
Helmut | (doubtfully) Well...
Mrs Helmut | Look!
| She opens the door wider to reveal heap of about ten bodies in the other room. There is dust rising from them and a big hole in the ceiling. Helmut goes to the door.
Helmut | Which one is Von Bülow?
| They walk round the pile. Mrs Helmut looks at a few bodies and then points.
Mrs Helmut | Here ... look!
Helmut | Oh, ja ... and Admiral Tirpitz!
| They are both momentarily overawed.
Mrs Helmut | Ja.
Helmut | And Von Müller... and Herr Reichner... and Hollweg and Von Graunberg...
Mrs Helmut | That isn't Graunberg - that's Graunberg... das ist Moltke...
| She lifts the body's head up by the hair as it's facing down.
Helmut | He's a lot older than I thought.
Mrs Helmut | He's a clever man, ja.
Helmut | ... and Zimmermann ... and Kimpte...
Mrs Helmut | What shall we do, Helmut?
Helmut | We must ring the Government.
Mrs Helmut | This is the Government, Helmut.
Helmut | Oh dear.
Mrs Helmut | It is a great honour to have so many members of the Government dead in our sitting room.
Helmut | Drawing room.
Mrs Helmut | Ja, well...
Helmut | There are no members of the Government dead in our sitting room.
Mrs Helmut | Ja, you know what I mean.
Helmut | Perhaps I should make a little speech or something?
Mrs Helmut | Not a speech, Helmut no...
Helmut | Shall we make them a cup of tea?
Mrs Helmut | It would be a waste of tea.
Helmut | But we must do something - so many important people in our drawing room - we must do something.
| They think for a little while.
Mrs Helmut | We could sort them out.
Helmut | And make a little list.
Mrs Helmut | Ja, ja. We could put the ministers for internal affairs over against the wall, and those for foreign here by the clock.
Helmut | And we can sort them out alphabetically?
Mrs Helmut | Nein, nein - just put the cleanest by the door.
Helmut | Ja.
| They start to hump the corpses around. Helmut starts to hump Von Bülow towards the clock.
Mrs Helmut | No, no! That's Von Bülow! He must go over here.
Helmut | That is my reading chair.
Mrs Helmut | He is the Reich Chancellor of Germany, Helmut.
| Helmut starts to take him towards the reading chair.
Helmut | All right ... but I think he would have been better up against the clock, you know.
Mrs Helmut | No, he would not look nice under the clock.
Helmut | I did not say under the clock. I said against the clock.
Mrs Helmut | Well then we could not see the clock!
Helmut | We could put the Minister for Colonies under the clock. He's small.
Mrs Helmut | No. Colonies are internal affairs. He must go against the wall. (Helmut lifts up the head of another corpse) Education!
| Helmut starts to drag him over to the wall.
Helmut | Soon we shall be able to make a list.
Mrs Helmut | Ja, ja, wait a minute! ... Who's that by the cat litter?
Helmut | I don't know. I've never seen him before.
Mrs Helmut | He is not a member of the Government. Get him out of here. Put him in the drawing room.
Helmut | He's in the drawing room, my dear.
Mrs Helmut | Ja, well you know what I mean.
Helmut | Put him in the sitting room.
Mrs Helmut | Ja, in, the sittng room, it's all the same.
Helmut | You can put him in the sitting room if he's in the drawing room.
| Cut to stock film of the zeppelin.
Voice Over | Count Ferdinand Von Zeppelin's behaviour on that flight in 1900 had incredible, far-reaching consequences, for one of the falling Ministers (cut to an old Edwardian photo of a German minister) the talented Herr Von Maintlitz, architect of the new Geman expansionist farm policy, fell on top of an old lady (old Edwardian photo of an elderly lady) in Nimwegen, killing her outright. Her daughter, Alice (old Edwardian photo of attractive young girl in the nude) suffered severe cerebral damage from the talented minister's (picture of Maintlitz again) heavy briefcase (Edwardian photo of a brief case) but was nursed back to life (another Edwardian erotic postcard) by an English doctor, Henderson. (a Muybridge photo of a nude man) Eventually, they married (Edwardian nude couple) and their eldest son, George Henderson ... (1930s nude man) was the father of Mike Henderson... (health and efficiency nudist camp group photo; a figure at the back is arrowed) producer and director of 'The Golden Age of Ballooning'.
| ANIMATION: balloons as before.
| SUPERIMPOSED CAPTION: 'GOLDEN AGE OF BALLOONING'
| Pointed surgical instruments fly on in formation and puncture the balloons.
| SUPERIMPOSED CAPTION: THE GOLDEN YEARS OF COLONIC IRRIGATION'
| Cut to black.
Voice Over | Mr and Mrs Rita Trondheim; Reginald Bo-sankway, who would be next to Norway in a rhyming dictionary, if it included proper names, and if he pronounced his name like that.
| Cut to a Victorian couple in the countyside.
| SUPERIMPOSED CAPTION: 'THE MILL ON THE FLOSS'
| SUPERIMPOSED CAPTION: 'PART I: BALLOONING'
| The couple rise slowly in the air. Fade out.